==> flink-1.13.6-src.tgz: flink-1.13.6/flink-runtime/src/main/java/org/apache/flink/runtime/checkpoint/StandaloneCheckpointRecoveryFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.checkpoint;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.jobmanager.HighAvailabilityMode;

/** {@link CheckpointCoordinator} components in {@link HighAvailabilityMode#NONE}. */
public class StandaloneCheckpointRecoveryFactory implements CheckpointRecoveryFactory {

    @Override
    public CompletedCheckpointStore createCheckpointStore(
            JobID jobId, int maxNumberOfCheckpointsToRetain, ClassLoader userClassLoader)
            throws Exception {

        return new StandaloneCompletedCheckpointStore(maxNumberOfCheckpointsToRetain);
    }

    @Override
    public CheckpointIDCounter createCheckpointIDCounter(JobID ignored) {
        return new StandaloneCheckpointIDCounter();
    }
}

==> flink-1.14.3-src.tgz: flink-1.14.3/flink-runtime/src/main/java/org/apache/flink/runtime/checkpoint/StandaloneCheckpointRecoveryFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.checkpoint;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.jobmanager.HighAvailabilityMode;

/** {@link CheckpointCoordinator} components in {@link HighAvailabilityMode#NONE}. */
public class StandaloneCheckpointRecoveryFactory implements CheckpointRecoveryFactory {

    @Override
    public CompletedCheckpointStore createRecoveredCompletedCheckpointStore(
            JobID jobId, int maxNumberOfCheckpointsToRetain, ClassLoader userClassLoader)
            throws Exception {

        return new StandaloneCompletedCheckpointStore(maxNumberOfCheckpointsToRetain);
    }

    @Override
    public CheckpointIDCounter createCheckpointIDCounter(JobID ignored) {
        return new StandaloneCheckpointIDCounter();
    }
}
